@@ -87,10 +87,6 @@ _supported_pyarrow_types = [
     ),
     pa.dictionary(pa.int8(), pa.string()),
     pa.map_(pa.string(), pa.int32()),
-]
-
-_unsupported_pyarrow_types = [
-    pa.decimal256(76, 38),
     pa.union(
         [pa.field("a", pa.binary(10)), pa.field("b", pa.string())],
         mode=pa.lib.UnionMode_DENSE,
@@ -113,6 +109,10 @@ _unsupported_pyarrow_types = [
     ),
 ]
 
+_unsupported_pyarrow_types = [
+    pa.decimal256(76, 38),
+]
+
 
 @pytest.mark.parametrize("pyarrow_type", _supported_pyarrow_types, ids=str)
 def test_type_roundtrip(pyarrow_type):
@@ -202,6 +202,9 @@ def test_empty_array_python(datatype):
     if datatype == pa.float16():
         pytest.skip("Float 16 is not implemented in Rust")
 
+    if type(datatype) is pa.lib.DenseUnionType or type(datatype) is pa.lib.SparseUnionType:
+        pytest.skip("Union is not implemented in Python")
+
     a = pa.array([], datatype)
     b = rust.round_trip_array(a)
     b.validate(full=True)
@@ -216,6 +219,9 @@ def test_empty_array_rust(datatype):
     """
     Rust -> Python
     """
+    if type(datatype) is pa.lib.DenseUnionType or type(datatype) is pa.lib.SparseUnionType:
+        pytest.skip("Union is not implemented in Python")
+
     a = pa.array([], type=datatype)
     b = rust.make_empty_array(datatype)
     b.validate(full=True)
@@ -352,6 +358,35 @@ def test_dictionary_python():
     del a
     del b
 
+def test_dense_union_python():
+    """
+    Python -> Rust -> Python
+    """
+    xs = pa.array([5, 6, 7])
+    ys = pa.array([False, True])
+    types = pa.array([0, 1, 1, 0, 0], type=pa.int8())
+    offsets = pa.array([0, 0, 1, 1, 2], type=pa.int32())
+    a = pa.UnionArray.from_dense(types, offsets, [xs, ys])
+
+    b = rust.round_trip_array(a)
+    assert a == b
+    del a
+    del b
+
+def test_sparse_union_python():
+    """
+    Python -> Rust -> Python
+    """
+    xs = pa.array([5, 6, 7])
+    ys = pa.array([False, False, True])
+    types = pa.array([0, 1, 1], type=pa.int8())
+    a = pa.UnionArray.from_sparse(types, [xs, ys])
+
+    b = rust.round_trip_array(a)
+    assert a == b
+    del a
+    del b
+
 def test_record_batch_reader():
     """
     Python -> Rust -> Python
