@@ -149,21 +149,37 @@ pub enum DataType {
     /// days can differ in length during day light savings time transitions).
     Interval(IntervalUnit),
     /// Opaque binary data of variable length.
+    ///
+    /// A single Binary array can store up to [`i32::MAX`] bytes
+    /// of binary data in total
     Binary,
     /// Opaque binary data of fixed size.
     /// Enum parameter specifies the number of bytes per value.
     FixedSizeBinary(i32),
     /// Opaque binary data of variable length and 64-bit offsets.
+    ///
+    /// A single LargeBinary array can store up to [`i64::MAX`] bytes
+    /// of binary data in total
     LargeBinary,
-    /// A variable-length string in Unicode with UTF-8 encoding.
+    /// A variable-length string in Unicode with UTF-8 encoding
+    ///
+    /// A single Utf8 array can store up to [`i32::MAX`] bytes
+    /// of string data in total
     Utf8,
     /// A variable-length string in Unicode with UFT-8 encoding and 64-bit offsets.
+    ///
+    /// A single LargeUtf8 array can store up to [`i64::MAX`] bytes
+    /// of string data in total
     LargeUtf8,
     /// A list of some logical data type with variable length.
+    ///
+    /// A single List array can store up to [`i32::MAX`] elements in total
     List(Box<Field>),
     /// A list of some logical data type with fixed length.
     FixedSizeList(Box<Field>, i32),
     /// A list of some logical data type with variable length and 64-bit offsets.
+    ///
+    /// A single LargeList array can store up to [`i64::MAX`] elements in total
     LargeList(Box<Field>),
     /// A nested datatype that contains a number of sub-fields.
     Struct(Vec<Field>),
@@ -190,6 +206,13 @@ pub enum DataType {
     /// * scale is the number of digits past the decimal
     ///
     /// For example the number 123.45 has precision 5 and scale 2.
+    ///
+    /// In certain situations, scale could be negative number. For
+    /// negative scale, it is the number of padding 0 to the right
+    /// of the digits.
+    ///
+    /// For example the number 12300 could be treated as a decimal
+    /// has precision 3 and scale -2.
     Decimal128(u8, i8),
     /// Exact 256-bit width decimal value with precision and scale
     ///
@@ -197,6 +220,13 @@ pub enum DataType {
     /// * scale is the number of digits past the decimal
     ///
     /// For example the number 123.45 has precision 5 and scale 2.
+    ///
+    /// In certain situations, scale could be negative number. For
+    /// negative scale, it is the number of padding 0 to the right
+    /// of the digits.
+    ///
+    /// For example the number 12300 could be treated as a decimal
+    /// has precision 3 and scale -2.
     Decimal256(u8, i8),
     /// A Map is a logical nested type that is represented as
     ///
@@ -264,16 +294,16 @@ impl fmt::Display for DataType {
 impl DataType {
     /// Returns true if the type is primitive: (numeric, temporal).
     #[inline]
-    pub fn is_primitive(t: &DataType) -> bool {
-        Self::is_numeric(t) || Self::is_temporal(t)
+    pub fn is_primitive(&self) -> bool {
+        self.is_numeric() || self.is_temporal()
     }
 
     /// Returns true if this type is numeric: (UInt*, Int*, Float*, Decimal*).
     #[inline]
-    pub fn is_numeric(t: &DataType) -> bool {
+    pub fn is_numeric(&self) -> bool {
         use DataType::*;
         matches!(
-            t,
+            self,
             UInt8
                 | UInt16
                 | UInt32
@@ -292,10 +322,10 @@ impl DataType {
 
     /// Returns true if this type is temporal: (Date*, Time*, Duration, or Interval).
     #[inline]
-    pub fn is_temporal(t: &DataType) -> bool {
+    pub fn is_temporal(&self) -> bool {
         use DataType::*;
         matches!(
-            t,
+            self,
             Date32
                 | Date64
                 | Timestamp(_, _)
@@ -308,19 +338,19 @@ impl DataType {
 
     /// Returns true if this type is valid as a dictionary key
     #[inline]
-    pub fn is_dictionary_key_type(t: &DataType) -> bool {
+    pub fn is_dictionary_key_type(&self) -> bool {
         use DataType::*;
         matches!(
-            t,
+            self,
             UInt8 | UInt16 | UInt32 | UInt64 | Int8 | Int16 | Int32 | Int64
         )
     }
 
     /// Returns true if this type is nested (List, FixedSizeList, LargeList, Struct, Union,
     /// or Map), or a dictionary of a nested type
-    pub fn is_nested(t: &DataType) -> bool {
+    pub fn is_nested(&self) -> bool {
         use DataType::*;
-        match t {
+        match self {
             Dictionary(_, v) => DataType::is_nested(v.as_ref()),
             List(_)
             | FixedSizeList(_, _)
